@@ -118,7 +118,7 @@ search.paths.ms <- function(obj,
         # Add the parameters with the largest MI
         #------------------------------------------------------#
         if (!all(is.na(mi_list))){
-          if (ms_allow | hybrid)
+          if (ms_allow)
           add_p     <- highest.mi(mi_list      = mi_list,
                                   indices      = indices,
                                   elig_paths   = elig_paths,
@@ -127,7 +127,7 @@ search.paths.ms <- function(obj,
                                   chisq_cutoff = chisq_cutoff,
                                   allow.mult   = TRUE,
                                   ms_tol       = ms_tol,
-                                  hybrid       = hybrid, 
+                                  hybrid       = hybrid,
                                   dir_prop_cutoff = dir_prop_cutoff)
           if (!ms_allow)
             add_p     <- highest.mi(mi_list      = mi_list,
