@@ -7,7 +7,10 @@ subgroupStage <- function(dat,
                           sub_feature,
                           sub_method,
                           ms_tol,
-                          ms_allow){
+                          ms_allow,
+                          sub_sim_thresh, 
+                          hybrid,
+                          dir_prop_cutoff){
 # Satisfy CRAN checks
   sub_membership = NULL
 
@@ -20,7 +23,10 @@ subgroupStage <- function(dat,
                                confirm_subgroup = confirm_subgroup,
                                out_path     = dat$out, 
                                sub_feature  = sub_feature,
-                               sub_method   = sub_method)
+                               sub_method   = sub_method, 
+                               sub_sim_thresh = sub_sim_thresh,
+                               hybrid       = hybrid,
+                               dir_prop_cutoff = dir_prop_cutoff)
 
   # begin subgroup-level search for paths ------------------------------------ #
 
